translate.storage.workflow.UnitState

Package translate :: Package storage :: Module workflow :: Class UnitState |
[hide private]
[frames] | no frames]

# Class UnitState

source code

Instance Methods | [hide private]
__init__(self, name, state_value) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
__repr__(self) repr(x) | source code
_enter(self, unit) | source code
Inherited from `State`: `__eq__`, `enter`, `leave` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, name, state_value) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### __repr__(self) (Representation operator) | source code
repr(x) Overrides: object.__repr__ (inherited documentation)